==> endeavour_2.8.2.orig.tar.gz: endeavour-2.8.2/endeavour2/edv_recbin_stat.c <==
#include <glib.h>

#include "edv_types.h"
#include "edv_obj.h"
#include "edv_recycled_obj.h"
#include "edv_recbin_index.h"
#include "edv_recbin_stat.h"


edv_recycled_object_struct *EDVRecBinObjectStat(
	const gchar *filename,
	const guint index
);


#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)

#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)


/*
 *	Gets the statistics of the recycled object in the recycle bin.
 *
 *	The filename specifies the full path to the recycle bin index
 *	file.
 *
 *	The index specifies the index of recycled object who stats are
 *	to be obtained.
 *
 *	Returns a dynamically allocated recycled object containing the
 *	statistics of the recycled object or NULL on error.
 */
edv_recycled_object_struct *EDVRecBinObjectStat(
	const gchar *filename,
	const guint index
)
{
	edv_recycled_object_struct *obj;

	if(STRISEMPTY(filename))
	    return(NULL);

	obj = EDVRecycledObjectNew();
	if(obj == NULL)
	    return(NULL);

	/* Open the recycle bin index file and get values for the
	 * recycled object
	 */
	if(EDVRecBinObjectGetFromIndexFile(filename, index, obj))
	{
	    /* Unable to get the recycled object's stats */
	    EDVRecycledObjectDelete(obj);
	    return(NULL);
	}

	return(obj);
}

==> endeavour_2.8.4.orig.tar.gz: endeavour-2.8.4/endeavour2/edv_recbin_stat.c <==
#include <errno.h>
#include <glib.h>

#include "edv_types.h"
#include "edv_obj.h"
#include "edv_recycled_obj.h"
#include "edv_recbin_index.h"
#include "edv_recbin_stat.h"


edv_recycled_object_struct *EDVRecBinObjectStat(
	const gchar *index_path,
	const guint index
);


#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)

#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)


/*
 *	Gets the statistics of the recycled object in the recycle bin.
 *
 *	The index_path specifies the full path to the recycle bin index
 *	file.
 *
 *	The index specifies the index of recycled object who stats are
 *	to be obtained.
 *
 *	Returns a dynamically allocated recycled object containing the
 *	statistics of the recycled object or NULL on error.
 */
edv_recycled_object_struct *EDVRecBinObjectStat(
	const gchar *index_path,
	const guint index
)
{
	edv_recycled_object_struct *obj;

	if(STRISEMPTY(index_path))
	{
	    errno = EINVAL;
	    return(NULL);
	}

	obj = EDVRecycledObjectNew();
	if(obj == NULL)
	    return(NULL);

	/* Open the recycle bin index file and get values for the
	 * recycled object
	 */
	if(EDVRecBinObjectGetFromIndexFile(index_path, index, obj))
	{
	    /* Unable to get the recycled object's stats */
	    const gint error_code = (gint)errno;
	    EDVRecycledObjectDelete(obj);
	    errno = (gint)error_code;
	    return(NULL);
	}

	return(obj);
}
